# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: timer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='timer.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0btimer.proto\"H\n\x0citimer_entry\x12\x0c\n\x04isec\x18\x01 \x02(\x04\x12\r\n\x05iusec\x18\x02 \x02(\x04\x12\x0c\n\x04vsec\x18\x03 \x02(\x04\x12\r\n\x05vusec\x18\x04 \x02(\x04\"\xbd\x01\n\x11posix_timer_entry\x12\r\n\x05it_id\x18\x01 \x02(\r\x12\x10\n\x08\x63lock_id\x18\x02 \x02(\r\x12\x10\n\x08si_signo\x18\x03 \x02(\r\x12\x17\n\x0fit_sigev_notify\x18\x04 \x02(\r\x12\x11\n\tsival_ptr\x18\x05 \x02(\x04\x12\x0f\n\x07overrun\x18\x06 \x02(\r\x12\x0c\n\x04isec\x18\x07 \x02(\x04\x12\r\n\x05insec\x18\x08 \x02(\x04\x12\x0c\n\x04vsec\x18\t \x02(\x04\x12\r\n\x05vnsec\x18\n \x02(\x04\"\x8d\x01\n\x11task_timers_entry\x12\x1b\n\x04real\x18\x01 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04virt\x18\x02 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04prof\x18\x03 \x02(\x0b\x32\r.itimer_entry\x12!\n\x05posix\x18\x04 \x03(\x0b\x32\x12.posix_timer_entry')
)




_ITIMER_ENTRY = _descriptor.Descriptor(
  name='itimer_entry',
  full_name='itimer_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isec', full_name='itimer_entry.isec', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iusec', full_name='itimer_entry.iusec', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsec', full_name='itimer_entry.vsec', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vusec', full_name='itimer_entry.vusec', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=87,
)


_POSIX_TIMER_ENTRY = _descriptor.Descriptor(
  name='posix_timer_entry',
  full_name='posix_timer_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='it_id', full_name='posix_timer_entry.it_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clock_id', full_name='posix_timer_entry.clock_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='si_signo', full_name='posix_timer_entry.si_signo', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='it_sigev_notify', full_name='posix_timer_entry.it_sigev_notify', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sival_ptr', full_name='posix_timer_entry.sival_ptr', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overrun', full_name='posix_timer_entry.overrun', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isec', full_name='posix_timer_entry.isec', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insec', full_name='posix_timer_entry.insec', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsec', full_name='posix_timer_entry.vsec', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vnsec', full_name='posix_timer_entry.vnsec', index=9,
      number=10, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=279,
)


_TASK_TIMERS_ENTRY = _descriptor.Descriptor(
  name='task_timers_entry',
  full_name='task_timers_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='real', full_name='task_timers_entry.real', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='virt', full_name='task_timers_entry.virt', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prof', full_name='task_timers_entry.prof', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posix', full_name='task_timers_entry.posix', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=423,
)

_TASK_TIMERS_ENTRY.fields_by_name['real'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['virt'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['prof'].message_type = _ITIMER_ENTRY
_TASK_TIMERS_ENTRY.fields_by_name['posix'].message_type = _POSIX_TIMER_ENTRY
DESCRIPTOR.message_types_by_name['itimer_entry'] = _ITIMER_ENTRY
DESCRIPTOR.message_types_by_name['posix_timer_entry'] = _POSIX_TIMER_ENTRY
DESCRIPTOR.message_types_by_name['task_timers_entry'] = _TASK_TIMERS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

itimer_entry = _reflection.GeneratedProtocolMessageType('itimer_entry', (_message.Message,), dict(
  DESCRIPTOR = _ITIMER_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:itimer_entry)
  ))
_sym_db.RegisterMessage(itimer_entry)

posix_timer_entry = _reflection.GeneratedProtocolMessageType('posix_timer_entry', (_message.Message,), dict(
  DESCRIPTOR = _POSIX_TIMER_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:posix_timer_entry)
  ))
_sym_db.RegisterMessage(posix_timer_entry)

task_timers_entry = _reflection.GeneratedProtocolMessageType('task_timers_entry', (_message.Message,), dict(
  DESCRIPTOR = _TASK_TIMERS_ENTRY,
  __module__ = 'timer_pb2'
  # @@protoc_insertion_point(class_scope:task_timers_entry)
  ))
_sym_db.RegisterMessage(task_timers_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ipc-var.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ipc-var.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ripc-var.proto\"\xfd\x02\n\ripc_var_entry\x12\x10\n\x08sem_ctls\x18\x01 \x03(\r\x12\x12\n\nmsg_ctlmax\x18\x02 \x02(\r\x12\x12\n\nmsg_ctlmnb\x18\x03 \x02(\r\x12\x12\n\nmsg_ctlmni\x18\x04 \x02(\r\x12\x13\n\x0b\x61uto_msgmni\x18\x05 \x02(\r\x12\x12\n\nshm_ctlmax\x18\x06 \x02(\x04\x12\x12\n\nshm_ctlall\x18\x07 \x02(\x04\x12\x12\n\nshm_ctlmni\x18\x08 \x02(\r\x12\x17\n\x0fshm_rmid_forced\x18\t \x02(\r\x12\x15\n\rmq_queues_max\x18\n \x02(\r\x12\x12\n\nmq_msg_max\x18\x0b \x02(\r\x12\x16\n\x0emq_msgsize_max\x18\x0c \x02(\r\x12\x16\n\x0emq_msg_default\x18\r \x01(\r\x12\x1a\n\x12mq_msgsize_default\x18\x0e \x01(\r\x12\x13\n\x0bmsg_next_id\x18\x0f \x01(\r\x12\x13\n\x0bsem_next_id\x18\x10 \x01(\r\x12\x13\n\x0bshm_next_id\x18\x11 \x01(\r')
)




_IPC_VAR_ENTRY = _descriptor.Descriptor(
  name='ipc_var_entry',
  full_name='ipc_var_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sem_ctls', full_name='ipc_var_entry.sem_ctls', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmax', full_name='ipc_var_entry.msg_ctlmax', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmnb', full_name='ipc_var_entry.msg_ctlmnb', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_ctlmni', full_name='ipc_var_entry.msg_ctlmni', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_msgmni', full_name='ipc_var_entry.auto_msgmni', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlmax', full_name='ipc_var_entry.shm_ctlmax', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlall', full_name='ipc_var_entry.shm_ctlall', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_ctlmni', full_name='ipc_var_entry.shm_ctlmni', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_rmid_forced', full_name='ipc_var_entry.shm_rmid_forced', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_queues_max', full_name='ipc_var_entry.mq_queues_max', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msg_max', full_name='ipc_var_entry.mq_msg_max', index=10,
      number=11, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msgsize_max', full_name='ipc_var_entry.mq_msgsize_max', index=11,
      number=12, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msg_default', full_name='ipc_var_entry.mq_msg_default', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mq_msgsize_default', full_name='ipc_var_entry.mq_msgsize_default', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_next_id', full_name='ipc_var_entry.msg_next_id', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sem_next_id', full_name='ipc_var_entry.sem_next_id', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shm_next_id', full_name='ipc_var_entry.shm_next_id', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=399,
)

DESCRIPTOR.message_types_by_name['ipc_var_entry'] = _IPC_VAR_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ipc_var_entry = _reflection.GeneratedProtocolMessageType('ipc_var_entry', (_message.Message,), dict(
  DESCRIPTOR = _IPC_VAR_ENTRY,
  __module__ = 'ipc_var_pb2'
  # @@protoc_insertion_point(class_scope:ipc_var_entry)
  ))
_sym_db.RegisterMessage(ipc_var_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: binfmt-misc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='binfmt-misc.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x11\x62infmt-misc.proto\"\x96\x01\n\x11\x62infmt_misc_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\x12\x13\n\x0binterpreter\x18\x03 \x02(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\t\x12\x11\n\textension\x18\x05 \x01(\t\x12\r\n\x05magic\x18\x06 \x01(\t\x12\x0c\n\x04mask\x18\x07 \x01(\t\x12\x0e\n\x06offset\x18\x08 \x01(\x05')
)




_BINFMT_MISC_ENTRY = _descriptor.Descriptor(
  name='binfmt_misc_entry',
  full_name='binfmt_misc_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='binfmt_misc_entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='binfmt_misc_entry.enabled', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interpreter', full_name='binfmt_misc_entry.interpreter', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='binfmt_misc_entry.flags', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension', full_name='binfmt_misc_entry.extension', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magic', full_name='binfmt_misc_entry.magic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='binfmt_misc_entry.mask', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='binfmt_misc_entry.offset', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=172,
)

DESCRIPTOR.message_types_by_name['binfmt_misc_entry'] = _BINFMT_MISC_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

binfmt_misc_entry = _reflection.GeneratedProtocolMessageType('binfmt_misc_entry', (_message.Message,), dict(
  DESCRIPTOR = _BINFMT_MISC_ENTRY,
  __module__ = 'binfmt_misc_pb2'
  # @@protoc_insertion_point(class_scope:binfmt_misc_entry)
  ))
_sym_db.RegisterMessage(binfmt_misc_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fdinfo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import regfile_pb2 as regfile__pb2
import sk_inet_pb2 as sk__inet__pb2
import ns_pb2 as ns__pb2
import packet_sock_pb2 as packet__sock__pb2
import sk_netlink_pb2 as sk__netlink__pb2
import eventfd_pb2 as eventfd__pb2
import eventpoll_pb2 as eventpoll__pb2
import signalfd_pb2 as signalfd__pb2
import tun_pb2 as tun__pb2
import timerfd_pb2 as timerfd__pb2
import fsnotify_pb2 as fsnotify__pb2
import ext_file_pb2 as ext__file__pb2
import sk_unix_pb2 as sk__unix__pb2
import fifo_pb2 as fifo__pb2
import pipe_pb2 as pipe__pb2
import tty_pb2 as tty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fdinfo.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0c\x66\x64info.proto\x1a\rregfile.proto\x1a\rsk-inet.proto\x1a\x08ns.proto\x1a\x11packet-sock.proto\x1a\x10sk-netlink.proto\x1a\reventfd.proto\x1a\x0f\x65ventpoll.proto\x1a\x0esignalfd.proto\x1a\ttun.proto\x1a\rtimerfd.proto\x1a\x0e\x66snotify.proto\x1a\x0e\x65xt-file.proto\x1a\rsk-unix.proto\x1a\nfifo.proto\x1a\npipe.proto\x1a\ttty.proto\"\x80\x01\n\x0c\x66\x64info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x17\n\x04type\x18\x03 \x02(\x0e\x32\t.fd_types\x12\n\n\x02\x66\x64\x18\x04 \x02(\r\x12\x1e\n\x16xattr_security_selinux\x18\x05 \x01(\t\x12\x10\n\x08out_jail\x18\x06 \x01(\x08\"\xc0\x04\n\nfile_entry\x12\x17\n\x04type\x18\x01 \x02(\x0e\x32\t.fd_types\x12\n\n\x02id\x18\x02 \x02(\r\x12\x1c\n\x03reg\x18\x03 \x01(\x0b\x32\x0f.reg_file_entry\x12\x1b\n\x03isk\x18\x04 \x01(\x0b\x32\x0e.inet_sk_entry\x12\x1b\n\x03nsf\x18\x05 \x01(\x0b\x32\x0e.ns_file_entry\x12\x1f\n\x03psk\x18\x06 \x01(\x0b\x32\x12.packet_sock_entry\x12\x1f\n\x04nlsk\x18\x07 \x01(\x0b\x32\x11.netlink_sk_entry\x12 \n\x03\x65\x66\x64\x18\x08 \x01(\x0b\x32\x13.eventfd_file_entry\x12#\n\x04\x65pfd\x18\t \x01(\x0b\x32\x15.eventpoll_file_entry\x12\x1d\n\x04sgfd\x18\n \x01(\x0b\x32\x0f.signalfd_entry\x12\x1c\n\x04tunf\x18\x0b \x01(\x0b\x32\x0e.tunfile_entry\x12\x1b\n\x03tfd\x18\x0c \x01(\x0b\x32\x0e.timerfd_entry\x12 \n\x03ify\x18\r \x01(\x0b\x32\x13.inotify_file_entry\x12!\n\x03\x66\x66y\x18\x0e \x01(\x0b\x32\x14.fanotify_file_entry\x12\x1c\n\x03\x65xt\x18\x0f \x01(\x0b\x32\x0f.ext_file_entry\x12\x1b\n\x03usk\x18\x10 \x01(\x0b\x32\x0e.unix_sk_entry\x12\x19\n\x04\x66ifo\x18\x11 \x01(\x0b\x32\x0b.fifo_entry\x12\x19\n\x04pipe\x18\x12 \x01(\x0b\x32\x0b.pipe_entry\x12\x1c\n\x03tty\x18\x13 \x01(\x0b\x32\x0f.tty_file_entry*\xfd\x01\n\x08\x66\x64_types\x12\x07\n\x03UND\x10\x00\x12\x07\n\x03REG\x10\x01\x12\x08\n\x04PIPE\x10\x02\x12\x08\n\x04\x46IFO\x10\x03\x12\n\n\x06INETSK\x10\x04\x12\n\n\x06UNIXSK\x10\x05\x12\x0b\n\x07\x45VENTFD\x10\x06\x12\r\n\tEVENTPOLL\x10\x07\x12\x0b\n\x07INOTIFY\x10\x08\x12\x0c\n\x08SIGNALFD\x10\t\x12\x0c\n\x08PACKETSK\x10\n\x12\x07\n\x03TTY\x10\x0b\x12\x0c\n\x08\x46\x41NOTIFY\x10\x0c\x12\r\n\tNETLINKSK\x10\r\x12\x06\n\x02NS\x10\x0e\x12\x08\n\x04TUNF\x10\x0f\x12\x07\n\x03\x45XT\x10\x10\x12\x0b\n\x07TIMERFD\x10\x11\x12\r\n\x07\x43TL_TTY\x10\xfe\xff\x03\x12\x11\n\x0b\x41UTOFS_PIPE\x10\xff\xff\x03')
  ,
  dependencies=[regfile__pb2.DESCRIPTOR,sk__inet__pb2.DESCRIPTOR,ns__pb2.DESCRIPTOR,packet__sock__pb2.DESCRIPTOR,sk__netlink__pb2.DESCRIPTOR,eventfd__pb2.DESCRIPTOR,eventpoll__pb2.DESCRIPTOR,signalfd__pb2.DESCRIPTOR,tun__pb2.DESCRIPTOR,timerfd__pb2.DESCRIPTOR,fsnotify__pb2.DESCRIPTOR,ext__file__pb2.DESCRIPTOR,sk__unix__pb2.DESCRIPTOR,fifo__pb2.DESCRIPTOR,pipe__pb2.DESCRIPTOR,tty__pb2.DESCRIPTOR,])

_FD_TYPES = _descriptor.EnumDescriptor(
  name='fd_types',
  full_name='fd_types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REG', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIFO', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INETSK', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIXSK', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENTFD', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENTPOLL', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INOTIFY', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNALFD', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PACKETSK', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TTY', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FANOTIFY', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETLINKSK', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NS', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TUNF', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXT', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMERFD', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CTL_TTY', index=18, number=65534,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTOFS_PIPE', index=19, number=65535,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=960,
  serialized_end=1213,
)
_sym_db.RegisterEnumDescriptor(_FD_TYPES)

fd_types = enum_type_wrapper.EnumTypeWrapper(_FD_TYPES)
UND = 0
REG = 1
PIPE = 2
FIFO = 3
INETSK = 4
UNIXSK = 5
EVENTFD = 6
EVENTPOLL = 7
INOTIFY = 8
SIGNALFD = 9
PACKETSK = 10
TTY = 11
FANOTIFY = 12
NETLINKSK = 13
NS = 14
TUNF = 15
EXT = 16
TIMERFD = 17
CTL_TTY = 65534
AUTOFS_PIPE = 65535



_FDINFO_ENTRY = _descriptor.Descriptor(
  name='fdinfo_entry',
  full_name='fdinfo_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='fdinfo_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='fdinfo_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='fdinfo_entry.type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fd', full_name='fdinfo_entry.fd', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xattr_security_selinux', full_name='fdinfo_entry.xattr_security_selinux', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_jail', full_name='fdinfo_entry.out_jail', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=378,
)


_FILE_ENTRY = _descriptor.Descriptor(
  name='file_entry',
  full_name='file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='file_entry.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='file_entry.id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reg', full_name='file_entry.reg', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isk', full_name='file_entry.isk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nsf', full_name='file_entry.nsf', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='psk', full_name='file_entry.psk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nlsk', full_name='file_entry.nlsk', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='efd', full_name='file_entry.efd', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epfd', full_name='file_entry.epfd', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sgfd', full_name='file_entry.sgfd', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tunf', full_name='file_entry.tunf', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfd', full_name='file_entry.tfd', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ify', full_name='file_entry.ify', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ffy', full_name='file_entry.ffy', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='file_entry.ext', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usk', full_name='file_entry.usk', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fifo', full_name='file_entry.fifo', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipe', full_name='file_entry.pipe', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tty', full_name='file_entry.tty', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=957,
)

_FDINFO_ENTRY.fields_by_name['type'].enum_type = _FD_TYPES
_FILE_ENTRY.fields_by_name['type'].enum_type = _FD_TYPES
_FILE_ENTRY.fields_by_name['reg'].message_type = regfile__pb2._REG_FILE_ENTRY
_FILE_ENTRY.fields_by_name['isk'].message_type = sk__inet__pb2._INET_SK_ENTRY
_FILE_ENTRY.fields_by_name['nsf'].message_type = ns__pb2._NS_FILE_ENTRY
_FILE_ENTRY.fields_by_name['psk'].message_type = packet__sock__pb2._PACKET_SOCK_ENTRY
_FILE_ENTRY.fields_by_name['nlsk'].message_type = sk__netlink__pb2._NETLINK_SK_ENTRY
_FILE_ENTRY.fields_by_name['efd'].message_type = eventfd__pb2._EVENTFD_FILE_ENTRY
_FILE_ENTRY.fields_by_name['epfd'].message_type = eventpoll__pb2._EVENTPOLL_FILE_ENTRY
_FILE_ENTRY.fields_by_name['sgfd'].message_type = signalfd__pb2._SIGNALFD_ENTRY
_FILE_ENTRY.fields_by_name['tunf'].message_type = tun__pb2._TUNFILE_ENTRY
_FILE_ENTRY.fields_by_name['tfd'].message_type = timerfd__pb2._TIMERFD_ENTRY
_FILE_ENTRY.fields_by_name['ify'].message_type = fsnotify__pb2._INOTIFY_FILE_ENTRY
_FILE_ENTRY.fields_by_name['ffy'].message_type = fsnotify__pb2._FANOTIFY_FILE_ENTRY
_FILE_ENTRY.fields_by_name['ext'].message_type = ext__file__pb2._EXT_FILE_ENTRY
_FILE_ENTRY.fields_by_name['usk'].message_type = sk__unix__pb2._UNIX_SK_ENTRY
_FILE_ENTRY.fields_by_name['fifo'].message_type = fifo__pb2._FIFO_ENTRY
_FILE_ENTRY.fields_by_name['pipe'].message_type = pipe__pb2._PIPE_ENTRY
_FILE_ENTRY.fields_by_name['tty'].message_type = tty__pb2._TTY_FILE_ENTRY
DESCRIPTOR.message_types_by_name['fdinfo_entry'] = _FDINFO_ENTRY
DESCRIPTOR.message_types_by_name['file_entry'] = _FILE_ENTRY
DESCRIPTOR.enum_types_by_name['fd_types'] = _FD_TYPES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

fdinfo_entry = _reflection.GeneratedProtocolMessageType('fdinfo_entry', (_message.Message,), dict(
  DESCRIPTOR = _FDINFO_ENTRY,
  __module__ = 'fdinfo_pb2'
  # @@protoc_insertion_point(class_scope:fdinfo_entry)
  ))
_sym_db.RegisterMessage(fdinfo_entry)

file_entry = _reflection.GeneratedProtocolMessageType('file_entry', (_message.Message,), dict(
  DESCRIPTOR = _FILE_ENTRY,
  __module__ = 'fdinfo_pb2'
  # @@protoc_insertion_point(class_scope:file_entry)
  ))
_sym_db.RegisterMessage(file_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sk-netlink.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sk-netlink.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10sk-netlink.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\"\xf1\x01\n\x10netlink_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\r\n\x05state\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0e\n\x06portid\x18\x07 \x02(\r\x12\x0e\n\x06groups\x18\x08 \x03(\r\x12\x12\n\ndst_portid\x18\t \x02(\r\x12\x11\n\tdst_group\x18\n \x02(\r\x12\x19\n\x04\x66own\x18\x0b \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0c \x02(\x0b\x32\x0e.sk_opts_entry\x12\r\n\x05ns_id\x18\r \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,sk__opts__pb2.DESCRIPTOR,])




_NETLINK_SK_ENTRY = _descriptor.Descriptor(
  name='netlink_sk_entry',
  full_name='netlink_sk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='netlink_sk_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='netlink_sk_entry.ino', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='netlink_sk_entry.protocol', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='netlink_sk_entry.state', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='netlink_sk_entry.flags', index=4,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portid', full_name='netlink_sk_entry.portid', index=5,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='netlink_sk_entry.groups', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_portid', full_name='netlink_sk_entry.dst_portid', index=7,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_group', full_name='netlink_sk_entry.dst_group', index=8,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='netlink_sk_entry.fown', index=9,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='netlink_sk_entry.opts', index=10,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='netlink_sk_entry.ns_id', index=11,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=301,
)

_NETLINK_SK_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_NETLINK_SK_ENTRY.fields_by_name['opts'].message_type = sk__opts__pb2._SK_OPTS_ENTRY
DESCRIPTOR.message_types_by_name['netlink_sk_entry'] = _NETLINK_SK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

netlink_sk_entry = _reflection.GeneratedProtocolMessageType('netlink_sk_entry', (_message.Message,), dict(
  DESCRIPTOR = _NETLINK_SK_ENTRY,
  __module__ = 'sk_netlink_pb2'
  # @@protoc_insertion_point(class_scope:netlink_sk_entry)
  ))
_sym_db.RegisterMessage(netlink_sk_entry)


_NETLINK_SK_ENTRY.fields_by_name['flags'].has_options = True
_NETLINK_SK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import vma_pb2 as vma__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mm.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x08mm.proto\x1a\nopts.proto\x1a\tvma.proto\">\n\x0e\x61io_ring_entry\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x0e\n\x06nr_req\x18\x02 \x02(\r\x12\x10\n\x08ring_len\x18\x03 \x02(\r\"\xce\x03\n\x08mm_entry\x12\x1c\n\rmm_start_code\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_code\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1c\n\rmm_start_data\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_data\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1d\n\x0emm_start_stack\x18\x05 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_start_brk\x18\x06 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x15\n\x06mm_brk\x18\x07 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_arg_start\x18\x08 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_arg_end\x18\t \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_env_start\x18\n \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_env_end\x18\x0b \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x0b\x65xe_file_id\x18\x0c \x02(\r\x12\x15\n\rmm_saved_auxv\x18\r \x03(\x04\x12\x18\n\x04vmas\x18\x0e \x03(\x0b\x32\n.vma_entry\x12\x10\n\x08\x64umpable\x18\x0f \x01(\x05\x12\x1d\n\x04\x61ios\x18\x10 \x03(\x0b\x32\x0f.aio_ring_entry\x12\x14\n\x0cthp_disabled\x18\x11 \x01(\x08')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,vma__pb2.DESCRIPTOR,])




_AIO_RING_ENTRY = _descriptor.Descriptor(
  name='aio_ring_entry',
  full_name='aio_ring_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='aio_ring_entry.id', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nr_req', full_name='aio_ring_entry.nr_req', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ring_len', full_name='aio_ring_entry.ring_len', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=97,
)


_MM_ENTRY = _descriptor.Descriptor(
  name='mm_entry',
  full_name='mm_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mm_start_code', full_name='mm_entry.mm_start_code', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_end_code', full_name='mm_entry.mm_end_code', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_start_data', full_name='mm_entry.mm_start_data', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_end_data', full_name='mm_entry.mm_end_data', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_start_stack', full_name='mm_entry.mm_start_stack', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_start_brk', full_name='mm_entry.mm_start_brk', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_brk', full_name='mm_entry.mm_brk', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_arg_start', full_name='mm_entry.mm_arg_start', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_arg_end', full_name='mm_entry.mm_arg_end', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_env_start', full_name='mm_entry.mm_env_start', index=9,
      number=10, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_env_end', full_name='mm_entry.mm_env_end', index=10,
      number=11, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exe_file_id', full_name='mm_entry.exe_file_id', index=11,
      number=12, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mm_saved_auxv', full_name='mm_entry.mm_saved_auxv', index=12,
      number=13, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vmas', full_name='mm_entry.vmas', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dumpable', full_name='mm_entry.dumpable', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aios', full_name='mm_entry.aios', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thp_disabled', full_name='mm_entry.thp_disabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=562,
)

_MM_ENTRY.fields_by_name['vmas'].message_type = vma__pb2._VMA_ENTRY
_MM_ENTRY.fields_by_name['aios'].message_type = _AIO_RING_ENTRY
DESCRIPTOR.message_types_by_name['aio_ring_entry'] = _AIO_RING_ENTRY
DESCRIPTOR.message_types_by_name['mm_entry'] = _MM_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

aio_ring_entry = _reflection.GeneratedProtocolMessageType('aio_ring_entry', (_message.Message,), dict(
  DESCRIPTOR = _AIO_RING_ENTRY,
  __module__ = 'mm_pb2'
  # @@protoc_insertion_point(class_scope:aio_ring_entry)
  ))
_sym_db.RegisterMessage(aio_ring_entry)

mm_entry = _reflection.GeneratedProtocolMessageType('mm_entry', (_message.Message,), dict(
  DESCRIPTOR = _MM_ENTRY,
  __module__ = 'mm_pb2'
  # @@protoc_insertion_point(class_scope:mm_entry)
  ))
_sym_db.RegisterMessage(mm_entry)


_MM_ENTRY.fields_by_name['mm_start_code'].has_options = True
_MM_ENTRY.fields_by_name['mm_start_code']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_end_code'].has_options = True
_MM_ENTRY.fields_by_name['mm_end_code']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_start_data'].has_options = True
_MM_ENTRY.fields_by_name['mm_start_data']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_end_data'].has_options = True
_MM_ENTRY.fields_by_name['mm_end_data']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_start_stack'].has_options = True
_MM_ENTRY.fields_by_name['mm_start_stack']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_start_brk'].has_options = True
_MM_ENTRY.fields_by_name['mm_start_brk']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_brk'].has_options = True
_MM_ENTRY.fields_by_name['mm_brk']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_arg_start'].has_options = True
_MM_ENTRY.fields_by_name['mm_arg_start']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_arg_end'].has_options = True
_MM_ENTRY.fields_by_name['mm_arg_end']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_env_start'].has_options = True
_MM_ENTRY.fields_by_name['mm_env_start']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MM_ENTRY.fields_by_name['mm_env_end'].has_options = True
_MM_ENTRY.fields_by_name['mm_env_end']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: utsns.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='utsns.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0butsns.proto\"3\n\x0butsns_entry\x12\x10\n\x08nodename\x18\x01 \x02(\t\x12\x12\n\ndomainname\x18\x02 \x02(\t')
)




_UTSNS_ENTRY = _descriptor.Descriptor(
  name='utsns_entry',
  full_name='utsns_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodename', full_name='utsns_entry.nodename', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domainname', full_name='utsns_entry.domainname', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=66,
)

DESCRIPTOR.message_types_by_name['utsns_entry'] = _UTSNS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

utsns_entry = _reflection.GeneratedProtocolMessageType('utsns_entry', (_message.Message,), dict(
  DESCRIPTOR = _UTSNS_ENTRY,
  __module__ = 'utsns_pb2'
  # @@protoc_insertion_point(class_scope:utsns_entry)
  ))
_sym_db.RegisterMessage(utsns_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: regfile.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='regfile.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rregfile.proto\x1a\nopts.proto\x1a\nfown.proto\"\xb0\x01\n\x0ereg_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x1f\n\x05\x66lags\x18\x02 \x02(\rB\x10\xd2?\r\x1a\x0brfile.flags\x12\x0b\n\x03pos\x18\x03 \x02(\x04\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry\x12\x0c\n\x04name\x18\x06 \x02(\t\x12\x12\n\x06mnt_id\x18\x07 \x01(\x11:\x02-1\x12\x0c\n\x04size\x18\x08 \x01(\x04\x12\x0b\n\x03\x65xt\x18\t \x01(\x08\x12\x0c\n\x04mode\x18\n \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,])




_REG_FILE_ENTRY = _descriptor.Descriptor(
  name='reg_file_entry',
  full_name='reg_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='reg_file_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='reg_file_entry.flags', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013rfile.flags')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='reg_file_entry.pos', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='reg_file_entry.fown', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='reg_file_entry.name', index=4,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mnt_id', full_name='reg_file_entry.mnt_id', index=5,
      number=7, type=17, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='reg_file_entry.size', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext', full_name='reg_file_entry.ext', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='reg_file_entry.mode', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=218,
)

_REG_FILE_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
DESCRIPTOR.message_types_by_name['reg_file_entry'] = _REG_FILE_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

reg_file_entry = _reflection.GeneratedProtocolMessageType('reg_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _REG_FILE_ENTRY,
  __module__ = 'regfile_pb2'
  # @@protoc_insertion_point(class_scope:reg_file_entry)
  ))
_sym_db.RegisterMessage(reg_file_entry)


_REG_FILE_ENTRY.fields_by_name['flags'].has_options = True
_REG_FILE_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\r\032\013rfile.flags'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ghost-file.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import time_pb2 as time__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ghost-file.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10ghost-file.proto\x1a\nopts.proto\x1a\ntime.proto\"\xc3\x01\n\x10ghost_file_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04mode\x18\x03 \x02(\r\x12\x12\n\x03\x64\x65v\x18\x04 \x01(\rB\x05\xd2?\x02 \x01\x12\x0b\n\x03ino\x18\x05 \x01(\x04\x12\x18\n\x04rdev\x18\x06 \x01(\rB\n\xd2?\x02 \x01\xd2?\x02(\x01\x12\x16\n\x04\x61tim\x18\x07 \x01(\x0b\x32\x08.timeval\x12\x16\n\x04mtim\x18\x08 \x01(\x0b\x32\x08.timeval\x12\x0e\n\x06\x63hunks\x18\t \x01(\x08\x12\x0c\n\x04size\x18\n \x01(\x04\"-\n\x11ghost_chunk_entry\x12\x0b\n\x03len\x18\x01 \x02(\x04\x12\x0b\n\x03off\x18\x02 \x02(\x04')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,time__pb2.DESCRIPTOR,])




_GHOST_FILE_ENTRY = _descriptor.Descriptor(
  name='ghost_file_entry',
  full_name='ghost_file_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='ghost_file_entry.uid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='ghost_file_entry.gid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='ghost_file_entry.mode', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dev', full_name='ghost_file_entry.dev', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ino', full_name='ghost_file_entry.ino', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rdev', full_name='ghost_file_entry.rdev', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='atim', full_name='ghost_file_entry.atim', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtim', full_name='ghost_file_entry.mtim', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunks', full_name='ghost_file_entry.chunks', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ghost_file_entry.size', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=240,
)


_GHOST_CHUNK_ENTRY = _descriptor.Descriptor(
  name='ghost_chunk_entry',
  full_name='ghost_chunk_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='len', full_name='ghost_chunk_entry.len', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off', full_name='ghost_chunk_entry.off', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=287,
)

_GHOST_FILE_ENTRY.fields_by_name['atim'].message_type = time__pb2._TIMEVAL
_GHOST_FILE_ENTRY.fields_by_name['mtim'].message_type = time__pb2._TIMEVAL
DESCRIPTOR.message_types_by_name['ghost_file_entry'] = _GHOST_FILE_ENTRY
DESCRIPTOR.message_types_by_name['ghost_chunk_entry'] = _GHOST_CHUNK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ghost_file_entry = _reflection.GeneratedProtocolMessageType('ghost_file_entry', (_message.Message,), dict(
  DESCRIPTOR = _GHOST_FILE_ENTRY,
  __module__ = 'ghost_file_pb2'
  # @@protoc_insertion_point(class_scope:ghost_file_entry)
  ))
_sym_db.RegisterMessage(ghost_file_entry)

ghost_chunk_entry = _reflection.GeneratedProtocolMessageType('ghost_chunk_entry', (_message.Message,), dict(
  DESCRIPTOR = _GHOST_CHUNK_ENTRY,
  __module__ = 'ghost_file_pb2'
  # @@protoc_insertion_point(class_scope:ghost_chunk_entry)
  ))
_sym_db.RegisterMessage(ghost_chunk_entry)


_GHOST_FILE_ENTRY.fields_by_name['dev'].has_options = True
_GHOST_FILE_ENTRY.fields_by_name['dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001'))
_GHOST_FILE_ENTRY.fields_by_name['rdev'].has_options = True
_GHOST_FILE_ENTRY.fields_by_name['rdev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001'))
# @@protoc_insertion_point(module_scope)
